==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/flac/translations/flac_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="zh_TW">
<defaultcodec></defaultcodec>
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="26"/>
        <source>FLAC Plugin</source>
        <translation>FLAC 插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="28"/>
        <source>FLAC Files</source>
        <translation>FLAC 檔案</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="82"/>
        <source>About FLAC Audio Plugin</source>
        <translation>關於 FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="83"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="84"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="61"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="67"/>
        <source>bits</source>
        <translation>位</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>FLAC Info</source>
        <translation>FLAC 資訊</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="183"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="86"/>
        <source>Length:</source>
        <translation>長度：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="103"/>
        <source>Sample rate:</source>
        <translation>取樣率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="123"/>
        <source>Channels:</source>
        <translation>音頻通道：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="136"/>
        <source>File size:</source>
        <translation>檔案大小：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="146"/>
        <source>Bitrate:</source>
        <translation>位速率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="173"/>
        <source>Sample width:</source>
        <translation>取樣頻寬：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>檔案路徑：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="322"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="199"/>
        <source>FLAC Tag</source>
        <translation>FLAC 標簽</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="299"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="270"/>
        <source>Track number:</source>
        <translation>音軌：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="257"/>
        <source>Year:</source>
        <translation>年代：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Genre:</source>
        <translation>流派：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="244"/>
        <source>Comment:</source>
        <translation>備註：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="231"/>
        <source>Album:</source>
        <translation>專輯：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="218"/>
        <source>Artist:</source>
        <translation>藝術家：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="205"/>
        <source>Title:</source>
        <translation>標題：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="65"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>詳細資料</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/flac/translations/flac_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="51"/>
        <source>FLAC Plugin</source>
        <translation>FLAC 插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Files</source>
        <translation>FLAC 檔案</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="120"/>
        <source>About FLAC Audio Plugin</source>
        <translation>關於 FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="121"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>Qmmp FLAC 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="122"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="61"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="67"/>
        <source>bits</source>
        <translation>位</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>FLAC Info</source>
        <translation>FLAC 資訊</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="79"/>
        <location filename="../detailsdialog.ui" line="96"/>
        <location filename="../detailsdialog.ui" line="113"/>
        <location filename="../detailsdialog.ui" line="159"/>
        <location filename="../detailsdialog.ui" line="166"/>
        <location filename="../detailsdialog.ui" line="183"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="86"/>
        <source>Length:</source>
        <translation>長度：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="103"/>
        <source>Sample rate:</source>
        <translation>取樣率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="123"/>
        <source>Channels:</source>
        <translation>音頻通道：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="136"/>
        <source>File size:</source>
        <translation>檔案大小：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="146"/>
        <source>Bitrate:</source>
        <translation>位速率：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="173"/>
        <source>Sample width:</source>
        <translation>取樣頻寬：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>檔案路徑：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="322"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="199"/>
        <source>FLAC Tag</source>
        <translation>FLAC 標簽</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="299"/>
        <source>Save</source>
        <translation>儲存</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="270"/>
        <source>Track number:</source>
        <translation>音軌：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="257"/>
        <source>Year:</source>
        <translation>年代：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="283"/>
        <source>Genre:</source>
        <translation>流派：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="244"/>
        <source>Comment:</source>
        <translation>備註：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="231"/>
        <source>Album:</source>
        <translation>專輯：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="218"/>
        <source>Artist:</source>
        <translation>藝術家：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="205"/>
        <source>Title:</source>
        <translation>標題：</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="65"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation>詳細資料</translation>
    </message>
</context>
</TS>
